Handler Executor
================

ASGI app for executing pre-resolved router nodes in per-app middleware chains.

HandlerExecutor
---------------

.. automodule:: genro_asgi.server.handler_executor
   :members:
   :undoc-members:
   :show-inheritance:
